package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````"!8``#0```!HD0````0`!30`(``(
M`"@`%P`6``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!@````8````!`````$````!````````````````````U(H`
M`-2*```%`````!````$```#,C0``S)T``,R=``!X`@``I`(```8`````$```
M`@```-2-``#4G0``U)T``/````#P````!@````0````$````3`$``$P!``!,
M`0``)````"0````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9,R-``#,G0``S)T``#0"```T`@``!`````$````O;&EB+VQD
M+6UU<VPM87)M:&8N<V\N,0`$````%`````,```!'3E4`7>X>FR4UM#F"!_-`
M;C0T)$:D1PP1````3`````@````(`````9`0`"5`!(`H@!`%H(90A("!``(+
M(`2-.(`208H$"`A,````30```%$```!6````5P```%\```!@````80``````
M``!C````9`````````!E````9@```&D```````````````&O-.AJ?YI\ZM/O
M#L[>1RUOQ=\?+L6;MKB-\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MO
M0OK7A^)'Q@%8[Y=YF$_#F[OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_
MJ9R;X*<""FH:GE"_VE<;H^#[20``````````````````````````6!``````
M```#``@```````"@`````````P`2``$``````````````!(````)````````
M```````2````$```````````````$0```.T!`````````````!$```!V`0``
M```````````2````%P``````````````$@```,8!`````````````!(````?
M```````````````2`````@,`````````````$@```/H!`````````````!(`
M``#2`0`````````````2````)@``````````````(`````T#````````````
M`"$````^```````````````2````1```````````````$@```$L`````````
M`````!(```##`@`````````````2````V0(`````````````$@```%(`````
M`````````!(````5`@`````````````2````60``````````````$@```)L"
M`````````````!(```!@```````````````2````:```````````````$@``
M`+P"`````````````!(```!P```````````````2````A`(`````````````
M$@```'@``````````````!(```"!```````````````@````T@(`````````
M````$@```)T``````````````!(```"B```````````````2````DP$`````
M````````%@```*("`````````````!(```!"`@`````````````2````JP``
M````````````$@```#0"`````````````!(```!1`P`````````````2````
MK0(`````````````$0````P#`````````````!$```!F`@`````````````2
M````\`(`````````````$@````X#`````````````!$```"R````````````
M```2````NP``````````````$0```(0!`````````````!(```#-````````
M```````B````W```````````````(````/(``````````````!(```"C````
M```````````2````4@(`````````````$@```/<``````````````"````"/
M`@`````````````2````$0$`````````````$@```+<!`````````````!(`
M```6`0`````````````2````=`(`````````````$@```!P!````````````
M`!(```"F`0`````````````2````*@$`````````````$@```#L!````````
M`````!(````0`@`````````````2````(0(`````````````$@```$$!````
M`````````!(```!;`@`````````````2````RP(`````````````$@```.@"
M`````````````!(```!0`0`````````````2````"P(`````````````$@``
M`%<!`````````````!(```!>`0`````````````2````"P,`````````````
M(0```&\!`````````````!(```!9!```<*`````````0`!,`_0(``$`3``#(
M`@``$@`*`.<!``#@2```!````!(`"P"3`P``S"T``+`&```2``H`:00``(@W
M```\`0``$@`*`'`#``#D'P``!````!(`"@`-!```6!````0````2``@`M@,`
M`'PT```,`P``$@`*`!,$``!$H````````!``$P!!!```Z!\``*0"```2``H`
M[@,``$2@````````$``3`($#``"D+```*`$``!(`"@"@`P``'!X``%@````2
M``H`J`,``*PI``"@````$@`*`,P#``#810``N`$``!(`"@#A`P``C"(``#``
M```2``H`^@,``'"@````````$``3``($``!,*@``<````!(`"@!D!```<*``
M```````0`!,`-@,``"P6``!H````$@`*`"$$``"\(@``K`$``!(`"@#7`P``
M0*````0````1`!(`.@0``$2@````````$``2`/,#```(%@```````!(`"@`*
M!```3$4``(P````2``H`/P,``(`L```D````$@`*`%H#``!T'@``<`$``!(`
M"@!.!```D$<``%`!```2``H`6`0``'"@````````$``3`"T$``!H)```1`4`
M`!(`"@``;W!E;F1I<@!M96UC;7``<W1D97)R`')E86QL;V,`86-C97-S`%]?
M9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``;65M
M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``<W1R<F-H<@!C;&]S961I<@!?
M251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!V9G!R:6YT9@!S=')C
M:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`
M7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A
M=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!M96UC<'D`<W1R;&5N`%]?<W1A
M8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C
M;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`7V9I
M;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E
M<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E
M<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U
M8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L
M;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``<W1R8W!Y`')E861D:7(`
M<W1R=&]K`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!S<')I;G1F`%]?;&EB8U]S
M=&%R=%]M86EN`'-N<')I;G1F`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C
M+FUU<VPM87)M:&8N<V\N,0!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE
M8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY
M7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`7U]E;F1?7P!P87)?
M9&EE`'-H85]I;FET`%]?8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN
M:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N
M9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L
M+T-/4D4``,R=```7````T)T``!<```"\GP``%P```,B?```7````U)\``!<`
M````H```%P```!"@```7````%*```!<````<H```%P```""@```7````)*``
M`!<````HH```%P```"R@```7````-*```!<````XH```%P```$"@```7````
MP)\``!4%``#$GP``%08``,R?```5#@``T)\``!4?``#8GP``$R,``-R?```5
M*0``X)\``!4M``#DGP``%2\``.B?```5,0``[)\``!4R``#PGP``%38``/2?
M```5.P``^)\``!4]``#\GP``%4$``-">```6`P``U)X``!8$``#8G@``%@<`
M`-R>```6"```X)X``!8)``#DG@``%@H``.B>```6"P``[)X``!8,``#PG@``
M%@T``/2>```6#@``^)X``!80``#\G@``%A$```"?```6$@``!)\``!83```(
MGP``%A0```R?```6%0``$)\``!86```4GP``%A<``!B?```6&```')\``!89
M```@GP``%AH``"2?```6&P``*)\``!8<```LGP``%AT``#"?```6'@``-)\`
M`!8@```XGP``%B$``#R?```6(@``0)\``!8D``!$GP``%B4``$B?```6)@``
M3)\``!8G``!0GP``%B@``%2?```6*P``6)\``!8L``!<GP``%BX``&"?```6
M,```9)\``!8Q``!HGP``%C(``&R?```6,P``<)\``!8T``!TGP``%C4``'B?
M```6-P``?)\``!8X``"`GP``%CD``(2?```6.@``B)\``!8\``",GP``%CX`
M`)"?```6/P``E)\``!9```"8GP``%D(``)R?```60P``H)\``!9$``"DGP``
M%D4``*B?```61@``K)\``!9'``"PGP``%D@``+2?```620``N)\``!9+```!
M0"WI`4"]Z![_+^$$X"WE!."?Y0[@C^`(\+[E4(X```#&C^((RHSB4/Z\Y0#&
MC^((RHSB2/Z\Y0#&C^((RHSB0/Z\Y0#&C^((RHSB./Z\Y0#&C^((RHSB,/Z\
MY0#&C^((RHSB*/Z\Y0#&C^((RHSB(/Z\Y0#&C^((RHSB&/Z\Y0#&C^((RHSB
M$/Z\Y0#&C^((RHSB"/Z\Y0#&C^((RHSB`/Z\Y0#&C^((RHSB^/V\Y0#&C^((
MRHSB\/V\Y0#&C^((RHSBZ/V\Y0#&C^((RHSBX/V\Y0#&C^((RHSBV/V\Y0#&
MC^((RHSBT/V\Y0#&C^((RHSBR/V\Y0#&C^((RHSBP/V\Y0#&C^((RHSBN/V\
MY0#&C^((RHSBL/V\Y0#&C^((RHSBJ/V\Y0#&C^((RHSBH/V\Y0#&C^((RHSB
MF/V\Y0#&C^((RHSBD/V\Y0#&C^((RHSBB/V\Y0#&C^((RHSB@/V\Y0#&C^((
MRHSB>/V\Y0#&C^((RHSB</V\Y0#&C^((RHSB:/V\Y0#&C^((RHSB8/V\Y0#&
MC^((RHSB6/V\Y0#&C^((RHSB4/V\Y0#&C^((RHSB2/V\Y0#&C^((RHSB0/V\
MY0#&C^((RHSB./V\Y0#&C^((RHSB,/V\Y0#&C^((RHSB*/V\Y0#&C^((RHSB
M(/V\Y0#&C^((RHSB&/V\Y0#&C^((RHSB$/V\Y0#&C^((RHSB"/V\Y0#&C^((
MRHSB`/V\Y0#&C^((RHSB^/R\Y0#&C^((RHSB\/R\Y0#&C^((RHSBZ/R\Y0#&
MC^((RHSBX/R\Y0#&C^((RHSBV/R\Y0#&C^((RHSBT/R\Y0#&C^((RHSBR/R\
MY0#&C^((RHSBP/R\Y0#&C^((RHSBN/R\Y0#&C^((RHSBL/R\Y0#&C^((RHSB
MJ/R\Y0#&C^((RHSBH/R\Y0#&C^((RHSBF/R\Y0#&C^((RHSBD/R\Y0#&C^((
MRHSBB/R\Y0#&C^((RHSB@/R\Y0`````!RJ#C<$`MZ0S`3>#(#XSE6,*?Y2C0
M3>)4,I_E'`"-Y1@0C>44((WE#,"/X`,PG.<8$(WB%""-XAP`C>(T4I_E`#"3
MY20PC>4`,*#CI?__ZR0BG^4%4(_@`B"5YQPRG^4,((WE`S"5YP(0H.$#`*#A
M$#"-Y5G__^L$,I_E`S"5YP!`T^4``%3C3P``"G`O'>[P,9_E'`"=Y0,PG^<#
M0(#B`R"2YP0`@.+^,]+E!P%PXP,P@^/^,\+E8```B@`!H.&:___K`#"@X;PA
MG^48$)WE`B"/X`!@DN6PP9_EL%&?Y;#AG^4<()WE``"1Y0S`C^`%4(_@#N"/
MX`$`4N-A0(/H!#",Y50``-H$`$'B#,"#X@(!@.`$X+'E`0!0X03@K.7[__\:
M`\""X@#@H.-H49_E:!&?Y050C^`,`)7E!""@X0#@C>4!$(_@#.&#YS[__^L`
M`%#C*0``"D11G^4@8(WB!5"/X`P`E>55___K`$"@X3`!G^4&$*#A``"/X-4`
M`.L``%#C(```"APQG^4#,(_@#`"3Y8S__^OL_O_K#"&?Y<PPG^4"((_@`S"2
MYP`@D^4D,)WE`B`SX``PH.,J```:!`"@X2C0C>)P@+WH+?__Z]P@G^4``%#C
M`B"/X`P`@N4?```*5___ZW`O'>[$,)_E`S"?YP,PDN?.1L/EH___Z@P`E>5&
M___KTO__Z@@`E>4``%#C`0``"HH(`.O9___JE`"?Y080H.$``(_@J0``ZP``
M4.,(`(7ETO__"O7__^IX,)_E>`"?Y0,PE><``(_@`Q"@X0PPC>7._O_K!,"@
MX[#__^H!`*#C)___ZUS__^M4BP``(`$``"B+```X`0``-`$````!``#XBP``
M*(P``"R,``!4.```5#@``.2+``#D"```N(L``'`U``",BP``V(D``$"+``"@
MB@``7#0``!@!```X-@```+"@XP#@H.,0$)_E`1"/X`T`H.$/P,#C#-"@X0``
M`.NXAP``!.`MY0#@H.,`(*#A1!"?Y40`G^4!$(_@``"1YQ303>(X,)_E"`"-
MY0,PD><PP)_E##"-Y03@C>4,$)'G`#"@X0`0C>4,`)WE!!"2Y.3^_^L4T(WB
M!/"=Y'R(```0`0``^`````0!```L`)_E+#"?Y0``C^`#,(_@``!3X2`PG^4#
M,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_AH(D``)R)```0B```#`$``#@`
MG^4X,)_E``"/X`,PC^``,$/@HQ^@X4,1@>`D,)_EP1"PX0,PC^`>_R\!&""?
MY0(PD^<``%/C'O\O`1/_+^%<B0``6(D``,"'```L`0```<J@XQ!`+>D,P$W@
M^`^,Y60PG^5D0)_E`S"/X``PT^4$0(_@``!3XQ"`O1A0,)_E`S"4YP``4^,"
M```*1#"?Y0,`G^>P_O_KQ___ZS@PG^4#,)3G``!3XP(```HL`)_E``"/X%3^
M_^L!(*#C(#"?Y0,PC^``(,/E$("]Z/R(``!TAP``)`$``)"(```(`0``0',`
M`*2(``!`,)_E0""?Y0,PC^`",)/G``!3XPH```H!RJ#C$$`MZ0S`3>#X#XSE
M(!"?Y2``G^4!$(_@``"/X)#^_^L00+WHM/__ZK/__^KTA@``*`$``%"(``#4
M<@```<J@X_!'+>D,P$W@X`^,Y<@PG^4`@%#B`S"/X"L```J\()_E`C"3YP"0
MD^4``%GC*```"@!0V.4!<*#A``!5XST`51,!4*`3`%"@`Q$``!H`0)GE``!4
MXPP```H)8*#A!2"@X0@0H.$$`*#A-_[_ZP``4.,"```:!3#4YST`4^,+```*
M!$"VY0``5./S__\:!`"@X?"'O>@(4*#A`3#UY0``4^,]`%,3^___&@A01>#F
M___J"6!&X`%0A>)&8:#A!4"$X`0`H.$`8(?E\(>]Z`A`H.'M___J"4"@X>O_
M_^J,A@``'`$```'*H.,00"WI#,!-X%@/C.6,()_EC#"?Y0(@C^"@T$WB`S"2
MYPT0H.$`,)/EG#"-Y0`PH.,`0*#A9/[_ZP``4.,``*`3!```&A`PG>4/.@/B
M"@I3XP$)4Q,*```*2""?Y4`PG^4"((_@`S"2YP`@D^6<,)WE`B`SX``PH.,'
M```:H-"-XA"`O>@"$*#C!`"@X<?]_^L0#V_AH`*@X>[__^I?_O_KI(4``"`!
M``!8A0```<J@X_!`+>D,P$W@2`^,Y50AG^54,9_E`B"/X`,PDN>DT$WB`%!0
MX@`PD^6<,(WE`#"@XP(```H`,-7E``!3XPH``!HH(9_E(#&?Y0(@C^`#,)+G
M`""3Y9PPG>4"(#/@`#"@XS\``!JDT(WB\("]Z)3]_^L`0%#B\?__"@0`H.&W
M_?_K``!0XR@```H3,-#E$V"`XBX`4^,"```:`3#6Y0``4^/T__\*$S#0Y2X`
M4^,C```*!0"@X2K^_^L`<*#A!@"@X2?^_^L``(?@`@"`XK+]_^L&,*#A`&"@
MX900G^4%(*#A`1"/X!7^_^L&`*#A#1"@X?W]_^L!`'#C!@"@X0,```H0,)WE
M#SH#X@$)4^,2```*GOW_ZP8`H.'\_?_K!`"@X8[]_^L``%#CUO__&@0`H.&K
M_?_K!0"@X>C]_^N____J`3#6Y2X`4^/8__\:`C#6Y0``4^/'__\*U/__ZJ;_
M_^OK___J`?[_Z_2$```@`0``P(0``.`N```!RJ#C\$<MZ0S`3>#8#XSE`4"@
MX1`BG^40,I_E`B"/X`,PDN<(T$WB`#"3Y00PC>4`,*#C`##1Y0!0H.$]`%/C
M`4"!`@0`H.'G_?_K#1"@X0!@H.$%`*#A(___Z]!QG^4`D%#B!W"/X$````K>
M_?_K``!6X3<``)JX,9_E`("=Y0-PE^<(@:#A`##5Y0``4^,]`%,3`3"@$P`P
MH`,%```*!3"@X0$@\^4``%+C/0!2$_O__QH%,$/@`@"&X@,`@.``8)?E5OW_
MZP``4.,(`(;G%0``"@4`H.$`,)?E"!"3YP$PT.0]`%/C``!3$P`PP>4&```*
M`2"!X@$PT.0"$*#A/0!3XP``4Q,!,,+D^?__&CTPH.,!(*#A`##!Y0$PU.0`
M`%/C`3#BY?O__QH((9_E^#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XS4`
M`!H(T(WB\(>]Z`&02>(!,-3D``!3XP$PZ>7[__\:[O__ZL`PG^4#<)?G`("7
MY0`PF.4``%/C)```"@@PH.$$(+/E"1"@X0``4N,!D(GB^O__&@,0@>(!$:#A
MD#"?Y0,PC^``()/E``!2XP\``!H!(*#C`0"@X0`@@^45_?_K`*!0XM7__PH(
M$*#A"8&@X0@@H.$2_?_K`*"'Y0`PH.,`D(WE`9")X@DQBN>B___J"`"@X=K\
M_^L``%#C`*"@X0``A^7%__\*"8&@X?+__^H#D*#A"!"@X]___^IR_?_K=(,`
M`"`!```L@P``'`$``%R"``"`@P```<J@XQ!`+>D,P$W@Z`^,Y7!/'>YL$)_E
M;#"?Y0$0C^`#,)'G$-!-XF``G^4,,(WE`R"@X0``G^=4,)_E5!"?Y0``E.<#
M,(_@`1"/X$;]_^L`P*#C0`"?Y4`PG^4``)_G/""?Y3P0G^4#,(_@``"4YP(@
MC^`($(WH`1"/X+;\_^L0T(WB$("]Z#"!```P`0``+((``'!L``#$*P``!((`
M`*@N``"4%@``L"L``#P0G^4\,)_E`1"/X`,PD>=PSQWN`R"@X0C03>(H`)_E
M!#"-Y0``G^<@,)_E(!"?Y0``G.<#,(_@`1"/X`C0C>(>_?_JF(```#`!``"0
M@0``U&L``"@K```!RJ#C<$`MZ0S`3>```(SE`<I,X@``C.4H``SE-"&?Y30Q
MG^4"VDWB&-!-X@(@C^`#,)+G`AJ-XA00@>(`,)/E`#"!Y0`PH..._/_K#,&?
MY0Q!G^4,(9_E#,"/X`Q@C>(`,*#A!!"@X08`H.$"((_@`,"-Y73\_^L!,(#B
M!`!3X3```(H!`'#C+P``"@%:C>(04(7B`2J@XP40H.$&`*#AP/S_ZP!`4.(G
M``"Z`0"$XHG\_^L`,%#B(P``"@4`4^$"```J!""#X`(`5>$=```Z!0!3X1@`
M`(J$()_E`@!4X1@``(H$(*#A`P"@X040H.'E_/_K`""@XP`PH.$$(,#G9!"?
MY5`@G^4!$(_@`@J-X@(@D><4`(#B`!"2Y0`@D.4!$#+@`""@XPD``!H#`*#A
M`MJ-XAC0C>)P@+WH!""%X`(`4^'C__\J\`#PYP`PH./J___JU?S_ZQR````@
M`0``\"H```$0``#0*@``0'\``*+__^H!RJ#C\$\MZ0S`3>```(SET``,Y5C"
MG^58(I_E0MU-XBS03>(,P(_@`%"@X4@"G^4"()SG0CV-X@APC>(!8*#A``"/
MX`<0H.$D,(/B`""2Y0`@@^4`(*#C]/W_ZR\0H.,`0*#A!0"@X6+\_^L``%#C
M$@``"@0"G^4%$*#A``"/X*_^_^L%`*#A]"&?Y>0QG^4"((_@0AV-X@,PDN<D
M$('B`""3Y0`PD>4"(#/@`#"@XVT``!I"W8WB+-"-XO"/O>@&`*#A//S_Z[@1
MG^4!$(_@BOS_ZP"@4.+E__\*`##:Y:2!G^6HD(WB``!3XPB`C^`$8$GB/P``
M"@``5.,$```*"A"@X00`H.$$_/_K``!0XR\```H*`*#AA/S_ZP$P0.(#,(K@
M`P!:X0`@H.$`L*#A`!"@,P`@BC`!,(HR`P``.@@``.H"`%/A`!#"Y0(```H!
MP'+E+P!<X_G__PH*`*#A<OS_ZP"PH.$%`*#A;_S_ZPL`@.`!`(#B`0I0X[S_
M_RH(P9_E"C"@X0S`C^`((*#A`1J@XP8`H.$$4(WE`,"-Y<S[_^L!`(#B`0I0
MXR\``(H'$*#A!@"@X3[\_^L``%#C`P``&I`P&>4/.@/B`@E3XQ4```JX$)_E
M``"@XP$0C^!&_/_K`*!0XJ'__PH`,-KE``!3X[___QH``%3C%@``"@`PU.4N
M`%/C`P``"H2@G^4!L*#C"J"/X-+__^H!,-3E``!3X^K__PKW___J`1"@XP8`
MH.&D^__K``!0X^3__QI4`)_E!A"@X0``C^`\_O_K!@"@X=C[_^N*___J/*"?
MY0&PH.,*H(_@OO__ZC+\_^OP`/#GL'X``"`!``"<*0``;"D``$1^```L*0``
M$"D``'PH```<*```Q"<``*`G``!T)P```<J@XQ!`+>D,P$W@^`^,Y2\0H.,`
M0*#AM?O_ZP``4.,!0(`2!`"@X1!`O>BY^__J`<J@XS!`+>D,P$W@``",Y1@`
M#.5T(9_E=#&?Y0':3>("((_@#-!-X@$:C>(#,)+G`%!0X@00@>(`,)/E`#"!
MY0`PH.,P```*`##5Y0``4^,M```*`/S_ZP$`@.(!"E#C.@``B@1`C>(%$*#A
M!`"@X9#[_^L$`*#A]_O_ZP$`0.(``(3@!`!0X0<``)H`(*#C`@``Z@0`4.$!
M(,#E`@``"@$P4.0O`%/C^?__"B\0H.,$`*#A@OO_ZP``4.,E```*!`!0X0`P
MH(,`,,"%!`"@X83[_^N\()_EM#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1
MY0(@,^``,*#C(@``&@':C>(,T(WB,("]Z(@@G^5\,)_E`B"/X`$:C>(#,)+G
M!!"!X@`@D^4`,)'E`B`SX``PH.,4```:8`"?Y0``C^`!VHWB#-"-XC!`O>AE
M^__J``"@X][__^I$()_E,#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@
M,^``,*#C(`"?!0``CP#L__\*M?O_Z^![```@`0``)'L``.QZ``#()0``H'H`
M`(`E```!RJ#C<$`MZ0S`3>#H#XSEQ"2?Y<0TG^4"((_@P%2?Y0,PDN>\9)_E
M"-!-X@50C^``,)/E!#"-Y0`PH.,&8(_@#4"@X000H.$&`*#AU_S_ZP``4.,.
M```*C#2?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@
MD^4``%+C!""#Y/O__QKK___J5&2?Y09@C^`$$*#A!@"@X<'\_^L``%#C#@``
M"C0TG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E
M``!2XP0@@^3[__\:Z___Z@!DG^4&8(_@!!"@X08`H.&K_/_K``!0XPX```K<
M,Y_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``
M4N,$((/D^___&NO__^JL8Y_E!F"/X`00H.$&`*#AE?S_ZP``4.,.```*A#.?
MY0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C
M!""#Y/O__QKK___J6&.?Y09@C^`$$*#A!@"@X7_\_^L``%#C#@``"BPSG^4`
M$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@
M@^3[__\:Z___Z@1CG^4&8(_@!!"@X08`H.%I_/_K``!0XPX```K4,I_E`!"=
MY0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D
M^___&NO__^JP8I_E!F"/X`00H.$&`*#A4_S_ZP``4.,.```*?#*?Y0`0G>4#
M,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O_
M_QKK___J7&*?Y09@C^`$$*#A!@"@X3W\_^L``%#C#@``"B0RG^4`$)WE`S"5
MYP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:
MZ___Z@ABG^4&8(_@!!"@X08`H.$G_/_K``!0XPX```K,,9_E`!"=Y0,PE><`
M()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO_
M_^JT89_E!F"/X`00H.$&`*#A$?S_ZP``4.,.```*=#&?Y0`0G>4#,)7G`""3
MY0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J
M8&&?Y09@C^`$$*#A!@"@X?O[_^L``%#C#@``"APQG^4`$)WE`S"5YP`@D^4!
M,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___Z@P!
MG^4$$*#A``"/X.;[_^L`$%#B`@``"O@`G^4``(_@IOS_Z_``G^4$$*#A``"/
MX-W[_^L`$%#B`@``"MP`G^4``(_@G?S_Z]0`G^4$$*#A``"/X-3[_^L`$%#B
M$@``"L``G^4``(_@E/S_Z[@@G^5D,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``
M,*#C$```&I@0G^68`)_E`1"/X```C^`(T(WB<$"]Z(3\_^J$`)_E!!"@X0``
MC^"[^__K`!!0XNG__PIP`)_E``"/X'O\_^OE___J=_K_ZSQZ```@`0``*'H`
M`$PE```<`0``_"0``*PD``!@)```$"0``,@C```,(P``)",``-@B``",(@``
MN"$``.0A``"X(0``U"$``-0A``#0(0``]"```-QU``"L(0``$"$``'PA````
M(0```<J@XP3@+>4,P$W@\`^,Y7@@G^5X,)_E`B"/X'0`G^4,T$WB`S"2YPT0
MH.$``(_@`#"3Y00PC>4`,*#CBOO_ZP``4.,%```*``#0Y0``4.,P`%`3`0"@
M`P``H!,!`"#B-""?Y2@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,!```:
M#-"-X@3PG>0Y^O_K^'0``"`!``!<(```J'0```'*H.,/`"WI!.`MY0S`3>#P
M#XSE1""?Y40PG^4"((_@`S"2YPS03>(`,)/E!#"-Y0`PH.,L,)_E+`"?Y10@
MC>(#,(_@`""-Y0`PD^<0$)WE``"3Y<7Y_^O_`*#CY_G_ZU1T```@`0``,'0`
M`/P`````P*#C\$<MZ0'HH.,,P$W@#N!,X`'*3.(``(SE#@!<X?O__QHX``[E
M`A"@XW3AG^5TP9_E`=A-XAC03>(.X(_@#,">YP%(C>(`(*#C`#"@XP#`G.44
MP(3E`,"@XP`0C>4`@*#A<OG_ZP%@4.(`<,'BQR^@X<<_)N`",%/@<S#_Y@(P
M(^`",%/@`B#"X`-@5N`"<,?@``!7XQ1`A.(W``"Z")&?Y0Q0C>(`$*#C!B"@
MX0<PH.$(`*#A`!"-Y5SY_^L!`''C`0!P`S(```H)(*#A!1"@X0@`H.&X^?_K
M`0!PXRD```H'`%#C'P``F@@`0.(`0)7@'```*K2@G^4*H(_@`@``Z@%`1.(%
M`%3A%@``.@@@H.,*$*#A!`"@X2GY_^L``%#C]O__&@5`1.`&`)3@Q!^GX'P@
MG^5L,)_E`B"/X`'(C>(#,)+G%,",X@`@D^4`,)SE`B`SX``PH.,0```:`=B-
MXAC0C>+PA[WH`6A6X@!PQ^(!`'?C`0AV`\G__QH``.#C`!"@X>G__^HH`)_E
M``"/X'W__^L@`)_E``"/X'K__^NO^?_KQ',``"`!```(``$`1'0``,1R``!X
M'@``7!X```'*H.,00"WI#,!-X/@/C.6F^?_K5_G_ZP``4.,``)`5$("]Z`'*
MH./P0"WI#,!-X-@/C.7P()_E\&"?Y?`PG^4"((_@%-!-X@,PDN<&8(_@`%"@
MX08`H.$($(WB`#"3Y0PPC>4`,*#CROK_ZP!`4.("```*`##4Y0``4^,.```:
ML""?Y:@PG^4"((_@`S"2YP`@D^4,,)WE`B`SX``PH.,@```:!1"@X8P`G^4`
M`(_@%-"-XO!`O>A[^__J!0"@X73Y_^L`<*#A!`"@X7'Y_^L``(?@`@"`XOSX
M_^M<,)_E7!"?Y04@H.$#,(_@`1"/X`!`C>4`0*#A7?G_ZT0@G^4L,)_E`B"/
MX`,PDN<`()/E##"=Y0(@,^``,*#C!!"@`08`H`'A__\*7?G_Z_QQ```$'@``
M(`$``+1Q``"D'0``>!P``'@<```X<0```<J@X_!/+>D,P$W@P`Z,Y4??3>+(
MH(WB"N"@X0`6G^4`QI_E`":?Y0$0C^`"()'G#,"/X`PPC.(8D(SBL%"-X@`@
MDN44(8WE`""@XP!PH.$'`)/H!P"%Z`\`N>@/`*[H`P"9Z##`C.*\0(WB`P".
MZ`<`G.@'`(3HL`6?Y1A@C>(&$*#A``"/X&_Z_^N@A9_E`)!0X@B`C^`"```*
M`##9Y0``4^,)`0`:+?G_Z][X_^L``%#C<@``"@"0D.4``%GC;P``"@D`H.$?
M^?_K@`"@X0$`@.*J^/_K`"#9Y0!`H.$``%+C%`"-Y0@```I$M9_E"["/X`0`
MH.$+$*#A"?G_ZP$@^>4"0(3B``!2X_C__QHD!9_E``"/X`(``.H$`+KE``!0
MXPT```H&$*#A1OK_ZP!`4.+X__\*`##4Y0``4^/U__\*>OK_ZP``4./R__\*
M!`"@X9_X_^L`0%#B#```&@1`E>0``%3C"0``"@`PU.4``%/CQ0``"@0`H.%L
M^O_K``!0X_'__QH$0)7D``!4X_7__QH$`*#AZ_C_ZQ20G>4`4*#A"0"@X>?X
M_^L`4(7@`5N%X@10A>(%`*#A</C_ZP20C>4`D*#A<#2?Y7`4G^4#,(_@`#"-
MY6@TG^4$(*#A`S"/X`$0C^#.^/_K!QV@XPD`H.&\^/_K`0!PXP,``!JV^/_K
M`,"0Y1$`7..E```:!A"@X0D`H.&Y^/_K`$!0XBP```H@))_E(!2?Y0(`F.<)
M,*#A`""7Y0``D.4!$(_@D?C_ZP!0H.,$))_EV#.?Y0(@C^`#,)+G`""3Y10Q
MG>4"(#/@`#"@X^D``!H%`*#A1]^-XO"/O>A6^/_K`)!0XH0``!H$`)3D``!0
MXPD```H&$*#A[/G_ZP`P4.+X__\*`##3Y0``4^/R__\:!`"4Y```4./U__\:
M#0"@XS#X_^N0DY_E4R"@XP!`H.$)D(_@%`"-Y83__^HH,)WE#SH#X@$)4^/.
M__\:,*"=Y9SX_^L``%KARO__&B@PG>6#.Z#AHSN@X0<-4^/%__\:!0"@X1OX
M_^L`4*#A/`.?Y080H.$``(_@R/G_ZP`04.)U```*``"7Y;C[_^L`H%#B<0``
M"@H`H.&`^/_K`P!0XP"`H.$,``":!!.?Y00`0.(``(K@`1"/X/3W_^L``%#C
M!0``&@0`6..7```*"("*X`4P6.4O`%/CDP``"M0"G^4&$*#A``"/X*SY_^L`
M`%#C`P``"@`PT.4P`%/C``!3$P0``!H`$*#C"@"@X0GX_^L`8%#B4@``&IP2
MG^6<`I_E`1"/X```C^!A^O_KU/?_ZXPBG^6,,I_EC!*?Y0(@C^"(@I_EB'*?
MY8ABG^4%`(WH`S"/X`D@H.$%`*#A`1"/X$7X_^L(@(_@!W"/X`9@C^`-``#J
M+OC_ZP`PD.41`%/C#@``&K[W_^L`P*#A`4"$X@@PH.$)(*#A!Q"@X04`H.%0
M`(WI`,"-Y3/X_^L'':#C!0"@X2'X_^L!`'#C[/__"@D`H.$@^/_K#`*?Y040
MH.$``(_@-OK_ZP4`H.&2_O_K;?__Z@-`H.$^___J*_C_ZX``H.$!`(#B"O__
MZIPAG^78$9_E`@"8YPDPH.$`()?E`1"/X`#`C>4``)#E[_?_ZUS__^J`_O_K
MM"&?Y4PQG^4"((_@`S"2YP`@D^44,9WE`B`SX``PH.-&```:"0"@X4??C>+P
M3[WHL_?_Z@"@E^6+___J]OW_ZP"`4>(`<*#AJ/__N@"@H.,*(%#B`##(X@8`
MH.$`H(WEX+"-XGGW_^L&(*#C"Q"@X08`H.'8]__K!@!0XS```!HX,9_EX""=
MY0,`4N&7__\:M"#;X2@QG^4#`%+AD___&C(@5^(`,,CB!@"@X0"@C>7H0(WB
M9??_ZR@@H.,&`*#A!!"@X<3W_^LH`%#C'```&O`@G^7P,)_E\!"?Y0(@C^`$
M((WE!0"@X0D@H.$`0(WE`S"/X`$0C^`0H<WEU/?_ZZ3__^H$<)?E``!7XVC_
M_PH'`*#AU_?_ZP,`4.-D__^:K!"?Y00`0.(``(?@`1"/X$SW_^L``%#C!Z"@
M`5S__^K/]__KC`"?Y0``C^"6_?_KR'````!R```@`0``=!L``%QP```L'```
MH!L``&`;``!`&P``0!H``/P````X&P``H&X``$@:``"H&@``<!H``-@8```8
M&0``F!@``,P:```D&```]!D``!`8``#X&0``G!H``'P7``!\&```%&P```!#
M04-(10``!!D``%P6```D&```V!<``,07```!RJ#C\$`MZ0S`3>#@#XSEC"*?
MY8PRG^4"((_@`S"2YPS03>(`,)/E!#"-Y0`PH.-P3QWN#6"@X6PRG^5L`I_E
M`S"?YP80H.$#4)3G``"/X&@PU>5I,,7ES_C_ZP``4.,"```*`##0Y3$`4^-B
M```*W?O_ZS@RG^4#,)_G`U"4YS`2G^4%`*#A`S"@XP$@H.,!$(_@+_?_ZP!0
M4.(,```*$""5Y1`RG^4`$)+E`S"?YP@BG^4#`)3G`B"/X"OW_^L0,)7E`!"3
MY0@PD>4!!1/C6@``&N@1G^4#,*#C`1"?YP$@H.,!`)3GV!&?Y0$0C^`8]__K
M`%!0X@L```K(`9_E!A"@X0``C^"C^/_K`"!0XCT```JT,9_E$!"5Y0,PG^<`
M$)'E`P"4YQ#W_^N@,9_EH!&?Y0,PG^<!(*#C`U"4YP$0C^`%`*#AM_;_ZX@A
MG^4`$*#A`B"/X`4`H.$#]__K`""@XW0QG^5T`9_E`S"?YP80H.$#,)3G``"/
MX&D@P^6%^/_K7$&?Y0``4.,$0(_@"`"$Y1````H'':#C)O?_ZP$P@.(1`%#C
M`0!3$S0``(HT(9_E[#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XRH``!H,
MT(WB\("]Z`0`E.7:_?_K``!0XP@`A.7I__\:^`"?Y0``C^"7]O_K`3#0Y0``
M4^.=__\*F/__ZOGY_^L`<%#B#@``"M0PG^40()7E`S"?YP`0DN4#`)3G!R"@
MX<[V_^L'`*#A`O?_Z[K__^JP,)_E`S"?YP,`E.>:]O_KG___ZJ`@G^6@,)_E
M`B"/X!`0E>4#,)_G!""2Y0`0D>4`()+E`P"4Y[SV_^NJ___J"/?_ZW@@G^4`
M,*#A=`"?Y0(@C^`&`)+I``"/X``0D>5M]O_K*&H``"`!```4:P``4!4``-QJ
M``#@%@``J&H``+P6``!X:@``D!8``%`4```X:@``(&H``$`6``!$%@``Z&D`
M`-`3``!0:@``B&@``*P5```T:0``$&D``(!I``#P:```3&D``"P5```!RJ#C
M,$`MZ0S`3>#H#XSE#"&?Y0PQG^4"((_@`$"@X00!G^4#,)+G#-!-X@T0H.$`
M`(_@`#"3Y00PC>4`,*#C$OC_ZP`P4.(*```*`##3Y0``4^,P`%,3`3"@`P`P
MH!,!,"/B``!4XP`PH`,!,`,2``!3XPH``!JP()_EI#"?Y0(@C^`#,)+G`""3
MY00PG>4"(#/@`#"@XR```!H,T(WB,("]Z``PU.4``%/C\?__"@0`H.&>^O_K
M+Q"@XP!0H.%,]O_K``!0XP%0@!(%`*#A4?;_ZU@0G^4$(*#C`1"/X#[V_^L`
M`%#CXO__&D0@G^4P,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C`P``&@0`
MH.$,T(WB,$"]Z$'X_^J=]O_K'&<``"`!``!\$@``M&8``)@2``!`9@``````
M``'*H./P3RWI#,!-X$`-C.50+)_E4#R?Y0(@C^`#,)+GI]]-X@`0H.$0P(WB
M`#"3Y90RC>4`,*#C#""@X0!`H.-``(#B@%"!XD!`$.DN-*#A_SP#XBX\@^$.
M=*#A#CR#X?]X!^((`(#B-N^_Y@<P@^$%`%#A`.""Y01`@N4(,(+E#$""Y1`@
M@N+N__\:@C^,XAQ`G>5XP)WE!#"-Y8@PG>484(WB"!"-Y04`H.$#$*#A#)"@
MX7P@G>48L)WE@("=Y81PG>6,X)WE$&"=Y12@G>4`0(WE#%"-Y0$``.H%L*#A
M`$"-Y0!`H.,!,*#A/,"0Y3@0D.4(4+#E=$"`Y01`D.4%$"'@"1`AX`3`+.`&
M$"'@`L`LX`K`+.`(D*#A`X"@X:$_H.&,,(/A`1"1X`,0@>$$,)WE!R"@X0``
M4^$.<*#A"V"@X0#@H.,`H)WE<!"`Y>'__QH($)WE#%"=Y0"0D>4(.Y_E""`5
MY2#@D>6I;:#A`0B1Z1"`D>48H)'E`R"2X(!BAN$.()+@B6*&X0S`D>4"8);@
M"B`HX"M!H.$+(`+@"B`BX`Q/A.$"8);@"T^$X1@@G>4IP:#A`,^,X00`*.`#
M()+@"0``X`H@DN`(`"#@"<^,X0``DN`(()7E#.`DX`,@DN`&X`[@!.`NX`@@
MDN#F#8#@#B"2X.#M@N`0()7E`R"2X`0@DN!F02S@`$`$X`Q`).`$()+@&$"5
MY6`!H.$#0)3@#,"4X&9!(.`.0`3@9D$DX.XM@N`$P)S@XDV,X"#`E>4#P)S@
M9L&,X&YA(.`"8`;@`&`FX`;`G.`H8)7E8B&@X0-@EN```);@;F$BX`1@!N!N
M82;@Y,V,X`8`D.#L;8#@,`"5Y0,`D.!N`8#@9.$BX`S@#N`"X"[@#@"0X#C@
ME>5LP:#A`^">X`(@GN!DX2S@!N`.X&3A+N#F#8#@#B"2X.#M@N!`()7E`R"2
MX&0A@N!F02S@`$`$X`Q`).`$()+@2$"5Y6`!H.$#0)3@#,"4X&9!(.`.0`3@
M9D$DX.XM@N`$P)S@XDV,X%#`E>4#P)S@9L&,X&YA(.`"8`;@`&`FX`;`G.!8
M8)7E8B&@X0-@EN```);@;F$BX`1@!N!N82;@Y,V,X`8`D.#L;8#@8`"5Y0,`
MD.!N`8#@9.$BX`S@#N`"X"[@#@"0X&C@E>5LP:#A`^">X`(@GN!DX2S@!N`.
MX&3A+N#F#8#@#B"2X.#M@N!P()7E`R"2X&0A@N!F02S@`$`$X`Q`).`$()+@
M>$"5Y6`!H.$#0)3@#,"4X&9!(.`.0`3@9D$DX.XM@N`$P)S@XDV,X(#`E>4#
MP)S@9L&,X&YA(.`"8`;@`&`FX`;`G.#D;8S@B,"5Y6(AH.$#P)S@``"<X&[!
M(N`$P`S@;L$LX`P`D.#FS8#@D`"5Y0,PD.!D`2+@!@``X`(`(.!N,8/@`#"3
MX.Q]@^"8`)7E+#B?Y69AH.$#`)#@H."5Y0(@D.!D`2;@#``@X``@DN`#`)[@
M9`&`X.?M@N"H0)7E;"$FX`<@(N`"`)#@9R&@X0-`E."P<)7E!D"4X&QA(N`.
M8";@[@V`X`9`E.`#8)?@;&&&X+APE>7@S83@;D$BX`!`).`$8);@8`&@X0-`
ME^`"0)3@P'"5Y>PMAN!N82#@#&`FX`9@E.`#0)?@;D&$X,APE>5LX2#@`N`N
MX.)MAN`.0)3@8B&@X0/@E^```)[@T'"5Y6SA(N`&X"[@#N"0X`,`E^#F383@
MV'"5Y6P!@.!FP2+@!,`LX.3MCN`,`)#@9$&@X0/`E^`"()S@X'"5Y6;!).`.
MP"S@#,"2X`,@E^#N#8#@Z'"5Y68A@N!N823@`&`FX.#-C.`&()+@8`&@X0-@
ME^`$8);@\'"5Y6Y!(.`,0"3@!$"6X`-@E^#L+8+@;F&&X/A0E>5LX2#@`N`N
MX.)-A.`.X);@8B&@X0-0E>``4)7@&&&=Y6P!(N`$`"#@Y.V.X```E>`#8);@
M[EV`X&S!AN!D`2+@(&&=Y0X`(.!NX:#A*'&=Y0``G.`#8);@9,$NX`(@EN`%
MP"S@Y0V`X`S`DN`#()?@X&V,X&0A@N!EP2[@,$&=Y0#`+.`,P)+@8`&@X0-`
ME.#F+8S@#N"4X&7!(.`X09WE!L`LX`S`GN`#X)3@9>&.X&9!(.!`49WE`D`D
MX.+-C.`$X)[@8B&@X0-0E>```)7@9D$BX$A1G>4,0"3@!$"0X`,`E>#L[8[@
M\#6?Y5!QG>5F`8#@;&$BX&Y1H.$.8";@[DV$X`9@D.!LX87A`P"7X`(`D.!8
M<9WEY"V&X`3@#N!L807@!N".X0[@D.`#<)?@9`&%X61A!>!LP8?@`@``X&!Q
MG>4&`(#AXNV.X`P`D.!B(:#A`\"7X`7`G.!D48+A9&$"X&AQG>4.4`7@!E"%
MX>X-@.`,4)7@`W"7X&[!@N%N80+@9$&'X`#`#.!P<9WE!L",X>!=A>`$0)S@
M8`&@X0/`E^`"P)S@Y2V$X&Y!@.%N80#@>'&=Y05`!.`&0(3A#$"4X`-PE^!E
MP8#A96$`X&[AA^`"P`S@@'&=Y0;`C.'B383@#N"<X&(AH.$#P)?@`,"<X.0-
MCN!EX8+A96$"X(AQG>4$X`[@!N".X0S@GN`#<)?@9,&"X61A`N!E48?@`,`,
MX)!QG>4&P(SAX.V.X`50G.!@`:#A`\"7X`+`G.#N+87@9%&`X61A`."8<9WE
M#E`%X`90A>$,4)7@`W"7X&[!@.%N80#@9$&'X`+`#."@<9WE!L",X>)=A>`$
M0)S@8B&@X0/`E^``P)S@Y0V$X&Y!@N%N80+@J'&=Y05`!.`&0(3A#$"4X`-P
ME^!EP8+A96$"X&[AA^``P`S@L'&=Y0;`C.'@383@#N"<X&`!H.$#P)?@`L"<
MX.0MCN!EX8#A96$`X+AQG>4$X`[@!N".X0S@GN`#<)?@9,&`X61A`.!E48?@
M`L`,X,!QG>4&P(SAXNV.X`50G.!B(:#A`\"7X`#`G.#N#87@9%&"X61A`N`.
M4`7@!E"%X0Q0E>!NP8+A;F$"X`#`#.`&P(SA`&"@X\AQG>7@787@`W"7X&1!
MA^#0<9WE8`&@X01`G.`#P)?@`L"<X.4MA.!N08#A!4`$X`1@@>4,8('E%&"!
MY1Q@@>5N80#@V'&=Y09`A.$,0)3@9<&`X0-PE^!E80#@`L`,X&[AA^`&P(SA
MX'&=Y>)-A.`.P)S@8B&@X>3MC.`#<)?@9<&"X65A`N```)?@!,`,X.AQG>4&
MP(SA`,"<X`-PE^!D`8+AZ#*?Y61A`N!E48?@#@``X/!QG>4&`(#A[LV,X`4`
MD.!NX:#A`U"7X`)0E>#X89WE9"$NX`P@(N#L#8#@`B"5X`-@EN#@78+@9$&&
MX&PA+N``8IWE`"`BX`(@E.!@`:#A`T"6X`Y`E.`(8IWE;.$@X`7@+N`.X)3@
M`T"6X.4M@N`08IWE;$&$X&7!(.`"P"S@XNV.X`S`E.!B(:#A`T"6X`!`E.`8
M8IWE90$BX`X`(.#NS8S@``"4X`-`EN!E083@(&*=Y>Q=@.!N`2+@#``@X```
ME.!LP:#A`T"6X`)`E.`H8IWE;B$LX`4@(N#E#8#@`B"4X`-@EN#@38+@;N&&
MX&4A+.`P8IWE`"`BX`(@GN!@`:#A`^"6X`S@GN`X8IWE9<$@X`3`+.#D+8+@
M#,">X`/@EN!EX8[@0&*=Y>)=C.!DP2#@`L`LX`S`GN!B(:#A`^"6X`#@GN!(
M8IWE9`$BX`4`(.#ES8S@``">X`/@EN!DX8[@4&*=Y>Q-@.!E`2+@#``@X```
MGN!LP:#A`^"6X`+@GN!88IWE92$LX`0@(N#D#8#@`B">X`/@EN!EX8[@8&*=
MY>!=@N!D(2S@`"`BX`(@GN!@`:#A`^"6X`S@GN!H8IWE9,$@X`7`+.#E+8+@
M#,">X`/@EN!DX8[@<&*=Y>)-C.!EP2#@`L`LX`S`GN!B(:#A`^"6X`#@GN!X
M8IWE90$BX`0`(.```)[@`^"6X.3-C.!EX8[@9&$BX(!2G>7L#8#@#&`FX&S!
MH.$&X)[@`U"5X&1A+.``8";@`B"5X`8@DN``8*#CB%*=Y>#MCN`#,)7@8*&*
MX`DPD^!@`2S@#@`@X&0Q@^``,)/@[BV"X.(]@^`@`)'E"R"2X&Z!B.`8H('E
M$("!Y0`P@>4((('E3""?Y0#`G.`P,)_E`B"/X"#`@>4D8('E`S"2YP`@D^64
M,IWE`B`SX``PH.,!```:I]^-XO"/O>A\\__KW&4``"`!``"9>8):H>O9;MR\
M&X_6P6+*O%D```'*H.,00"WI#,!-X/@/C.6``*#C^O+_ZP][G^T`>X#M#WN?
M[0)[@.T/>Y_M!'N`[0][G^T&>X#M#WN?[0`@H.,(>X#M#GN?[7@@@.4*>X#M
M#'N`[1"`O>@`\"#C`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#P
MX=+#`````````````````<J@X_!'+>D,P$W@X`^,Y0)0H.$`,*#C`:"@X2@0
MD.4L()#EA<&!X`$`7.$"(-/@`&"@X3`@D.4T$)#EQ0^@X0$``"H!()+B`!"A
MXBPPAN6E/J#A@#&#X0(PD^"@'J'@>`"6Y2C`AN4``%#C,#"&Y300AN4X@(8"
M%@``"D!`8.(X@(;B!0!4X0``B.`%0*"A"@!0X4(``"H$,(#@`P!:X01PBB`Y
M```Z"A"@X00@H.$<\__K>#"6Y0,PA.!``%/C>#"&Y?"'O1@&`*#AA_S_ZP>@
MH.$$4$7@/P!5XQL``-H*0*#A>)"&XD!PBN($`%CA(@``*@D`5.$D```Z!Z"@
MX0@PH.%`X(3B`,"4Y00`E.4($)3E#""4Y1!`A.(.`%3A`,"#Y00`@^4($(/E
M#""#Y1`P@^+S__\:!@"@X4!01>)J_/_K/P!5XT!PA^+F___*"@!8X0X``#H"
M``":!3"*X`,`6.$)```Z!2"@X0H0H.$(`*#AZ_+_ZWA0AN7PA[WH!Z"@X=W_
M_YH'`%CAV___*O``\.<%,(C@`P!:X?'__RKZ___J!'"*X+[__YH'`%#AO/__
M*O7__^H!RJ#C\$$MZ0S`3>#H#XSE?R#@XR@PD>4P8)'E,W^_YJ,QH.$_,`/B
M`<"#XCB`@>(X`%SC`4"@X0!0H.$V;[_F`R#(YSP``-H`$*#C0"!LX@P`B.!0
M\O_K!`"@X37\_^LX(*#C`!"@XP@`H.%*\O_K!`"@X?!GQ.$N_/_K`S#4Y00`
MH.$`,,7ELC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%Y0LPU.4$,,7ENC#4
MX04PQ>4(,)3E(S2@X08PQ>4(,)3E!S#%Y1,PU.4(,,7ELC'4X0DPQ>40,)3E
M(S2@X0HPQ>40,)3E"S#%Y1LPU.4,,,7ENC'4X0TPQ>48,)3E(S2@X0XPQ>48
M,)3E#S#%Y2,PU.40,,7ELC+4X1$PQ>4@,)3E(S2@X1(PQ>4@,)3E$S#%Y?!!
MO>A]\O_J`!"@XPP`B.`X(&SB$_+_Z\?__^H!0"WI`4"]Z![_+^$^````00``
M``P```!!````$0```$$````G````00```#8```!!`````P```$$````&````
M00```!4```!!````#P```$$````.````00```"8```!!````$P```$$````I
M````00````(```!!````&0```$$````*````00````L```!!````````````
M```E<R\E<P```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0
M`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`
M````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%
M1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#
M2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````
M4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`
M````,0```&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9`!,1%],24)205)9
M7U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N
M<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I
M;VXI"@``4$%42`````!P87)L`````"YP87(`````<VAO<G0@<F5A9```)7,E
M<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S
M`````!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q
M+C`V,P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H`````+64``"TM``!54T52`````%5315).04U%
M`````%1%35!$25(`5$U0`"]T;7``````979A;"`G97AE8R`O=7-R+V)I;B]P
M97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)
M0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)
M3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S
M:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`[
M"B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?
M;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@
M,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H
M)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/
M5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H
M)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U
M9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@
M)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N
M("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M
M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D
M=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M
M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A
M<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I
M('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP
M6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL
M96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M
M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L
M965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN
M+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@
M/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I
M.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N
M86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ
M0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D
M7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL
M"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z
M("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE
M(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD
M14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R
M=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@
M)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M
M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@
M:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?
M<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@
M,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!
M1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T
M<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<
M,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<
M,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S
M="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=
M*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@
M,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F
M<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T
M87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*
M<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP
M86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U
M;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X
M="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@
M>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R
M8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES
M='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D
M=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD
M(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE
M+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z
M("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]
M*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M
M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D
M9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P
M<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@
M0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ
M1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I
M<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N
M86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[
M"GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D
M8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A
M9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T
M($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@
M("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H
M)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL
M92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M
M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C
M;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U
M;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%2
M1U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*
M:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*
M?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E
M860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D
M8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE
M<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50
M871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z
M.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T
M92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@
M/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D
M97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*
M)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C
M=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*
M;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE
M<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`
M:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^
M(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO
M9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]
M("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N
M=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[
M"GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR
M87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T[
M"B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&
M24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B
M)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT
M*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT
M96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O
M("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]
M"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI
M('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN
M960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@
M)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA
M;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S
M:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?
M;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T
M*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@
M)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D
M9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0
M?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI
M<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@
M870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN
M9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II
M<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?
M;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%2
M1U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D
M=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T
M:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z
M.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A
M=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H
M*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D
M=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I
M<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,[
M"G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q
M=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@
M4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U
M8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D
M,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D
M("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M
M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M
M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF
M("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS
M92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@
M?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI
M;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI
M('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D
M9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A
M<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@
M)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@
M)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H
M)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D
M1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE
M7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I
M>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F
M(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M
M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]
M"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE
M+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A
M<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E
M;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G
M/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF
M)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N
M86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@
M)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK
M*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P
M<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D
M,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD
M(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US
M("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G
M;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL*
M*"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[
M7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO
M)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB
M4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@
M+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I
M9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@!P97)L>'-I+F,`````0T%#2$4``#X```!!````#````$$````1````00``
M`"<```!!````-@```$$````#````00````8```!!````%0```$$````/````
M00````X```!!````)@```$$````3````00```"D```!!`````@```$$````9
M````00````H```!!````"P```$$`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````P!<``"@7```!````%@,`
M``$````A`P``'0```'4$```,````6!````T```#@2```&0```,R=```;````
M!````!H```#0G0``'`````0```#U_O]O<`$```4```#\"```!@```%P"```*
M````DP0```L````0````%0`````````#````Q)X```(```#8`0``%````!$`
M```7````@`X``!$```"0#0``$@```/`````3````"````!X````(````^___
M;P$```CZ__]O$```````````````````````````````````````````````
M``````````#4G0````````````!D$```9!```&00``!D$```9!```&00``!D
M$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00
M``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```9!``
M`&00``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```
M9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D
M$```9!```&00``!D$```9!```&00``!D$```9!```$`3`````````````.!(
M`````````````%@0````````````````````````````````````````````
M`````````````*````I005(N<&T*`````+1,``#(20```````(A*``",2@``
MJ$P``-!)``"P3````````)1,``"<3````````+Q,``!'0T,Z("A!;'!I;F4@
M,3,N,BXQ7V=I=#(P,C0P,S`Y*2`Q,RXR+C$@,C`R-#`S,#D`03(```!A96%B
M:0`!*`````4V2UH`!@<(`0D!"@(2!!,!%`$5`1<#&`$:`AP!'@(B`40!`"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M``````L````!`````@```#0!```T`0``&````````````````0`````````3
M````!P````(```!,`0``3`$``"0```````````````0`````````)@```/;_
M_V\"````<`$``'`!``#L````!``````````$````!````#`````+`````@``
M`%P"``!<`@``H`8```4````#````!````!`````X`````P````(```#\"```
M_`@``),$``````````````$`````````0`````D````"````D`T``)`-``#P
M````!``````````$````"````$D````)````0@```(`.``"`#@``V`$```0`
M```1````!`````@```!2`````0````8```!8$```6!````P`````````````
M``0`````````30````$````&````9!```&00``#8`@`````````````$````
M!````%@````!````!@```$`3``!`$P``H#4`````````````"`````````!>
M`````0````8```#@2```X$@```P```````````````0`````````9`````$`
M```"````[$@``.Q(``#D00`````````````$`````````&P````!`````@``
M`-"*``#0B@``!```````````````!`````````!V````#@````,```#,G0``
MS(T```0```````````````0````$````@@````\````#````T)T``-"-```$
M```````````````$````!````(X````&`````P```-2=``#4C0``\`````4`
M````````!`````@```"7`````0````,```#$G@``Q(X``#P!````````````
M``0````$````G`````$````#`````*````"0``!$```````````````$````
M`````*(````(`````P```$2@``!$D```+```````````````!`````````"G
M`````0```#``````````1)```#$```````````````$````!````L`````,`
M`'```````````'60```S```````````````!``````````$````#````````
=``````"HD```P````````````````0``````````
